@@ -1,6 +1,6 @@
 class ObjectDisposedException(Exception):
     def __init__(self):
-        super().__init__("The operation was canceled")
+        super().__init__("Cannot access a disposed object")
 
 
 class OperationCanceledError(Exception):
